@@ -88,12 +88,6 @@ class DataCenter(object):
         """
         self.location = location or DEFAULT_LOCATION
         self.known_locations = known_locations or KNOWN_LOCATIONS
-        if self.location in self.known_locations:
-            self.base_url = self.known_locations[self.location]
-        elif '.' in self.location or self.location == 'localhost':
-            self.base_url = 'https://' + self.location
-        else:
-            self.base_url = 'https://' + self.location + API_HOST_SUFFIX
         self.config = config or {}
         if key_id and secret:
             self.auth = HTTPSignatureAuth(key_id=key_id, secret=secret)
@@ -130,13 +124,39 @@ class DataCenter(object):
         return '<{module}.{cls}: {name}at <{loc}>>'.format(
             module=self.__module__, cls=self.__class__.__name__, 
             name=user_string, loc=self.location)
-        
+    
+    def __eq__(self, other):
+        """
+        Not all DataCenters are created equal.
+        """
+        if isinstance(other, DataCenter):
+            if self.login == 'my':
+                self.me()
+            if other.login == 'my':
+                other.me()
+            return self.url == other.url
+        else:
+            return False
+    
+    def __ne__(self, other):
+        return not self.__eq__(other)
+    
     @property
     def url(self):
         """Base URL for SmartDC requests"""
         return '{base_url}/{login}/'.format(base_url=self.base_url, 
             login=self.login)
     
+    @property
+    def base_url(self):
+        """Protocol + hostname"""
+        if self.location in self.known_locations:
+            return self.known_locations[self.location]
+        elif '.' in self.location or self.location == 'localhost':
+            return 'https://' + self.location
+        else:
+            return 'https://' + self.location + API_HOST_SUFFIX
+    
     def authenticate(self, key_id=None, secret=None):
         """
         :param key_id: SmartDC identifier for the ssh key
@@ -176,6 +196,8 @@ class DataCenter(object):
         resp = requests.request(method, full_path, auth=self.auth, 
             headers=request_headers, config=self.config, **kwargs)
         if 400 <= resp.status_code < 499:
+            if resp.content:
+                print >> sys.stderr, resp.content
             resp.raise_for_status()
         if resp.content:
             if resp.headers['content-type'] == 'application/json':
@@ -335,7 +357,11 @@ class DataCenter(object):
         Requests all the datasets in this datacenter, filters for the default, 
         and returns the corresponding :py:class:`dict`.
         """
-        return filter(itemgetter('default'), self.datasets())[0]
+        sets = filter(itemgetter('default'), self.datasets())
+        if sets:
+            return sets[0]
+        else:
+            return None
     
     def dataset(self, dataset_id):
         """
@@ -382,7 +408,11 @@ class DataCenter(object):
         Requests all the packages in this datacenter, filters for the default, 
         and returns the corresponding dict.
         """
-        return filter(itemgetter('default'), self.datasets())[0]
+        packages = filter(itemgetter('default'), self.packages())
+        if packages:
+            return packages[0]
+        else:
+            return None
     
     def package(self, name):
         """
